measuretools.iterate_measures_forward_in_expr
=============================================

.. autofunction:: abjad.tools.measuretools.iterate_measures_forward_in_expr.iterate_measures_forward_in_expr
